# pyslsqp.postprocessing

```{eval-rst}

.. autosummary::
    pyslsqp.postprocessing.print_file_contents 
    pyslsqp.postprocessing.load_results
    pyslsqp.postprocessing.load_attributes
    pyslsqp.postprocessing.load_variables
    pyslsqp.postprocessing.visualize
    pyslsqp.postprocessing.print_dict_as_table

```

```{eval-rst}

.. autofunction:: pyslsqp.postprocessing.print_file_contents

.. autofunction:: pyslsqp.postprocessing.load_results

.. autofunction:: pyslsqp.postprocessing.load_attributes

.. autofunction:: pyslsqp.postprocessing.load_variables

.. autofunction:: pyslsqp.postprocessing.visualize

.. autofunction:: pyslsqp.postprocessing.print_dict_as_table

```